#define OPEQ MFB_OPEQ_BLACK
#define MFBPOLYGLYPHBLT mfbPolyGlyphBltBlack
#include "../../mfb/mfbplygblt.c"
